Signed-off-by: Tomas Winkler <[email protected]>
---
 drivers/misc/mei/bus.c     | 4 ++--
 drivers/misc/mei/init.c    | 2 +-
 drivers/misc/mei/mei_dev.h | 5 ++---
 drivers/misc/mei/nfc.c     | 4 ++--
 4 files changed, 7 insertions(+), 8 deletions(-)

diff --git a/drivers/misc/mei/bus.c b/drivers/misc/mei/bus.c
index a40be68dd7aa..2ae7e521f029 100644
--- a/drivers/misc/mei/bus.c
+++ b/drivers/misc/mei/bus.c
@@ -203,7 +203,7 @@ struct mei_cl *mei_cl_bus_find_cl_by_uuid(struct mei_device 
*bus,
 {
        struct mei_cl *cl;
 
-       list_for_each_entry(cl, &bus->device_list, device_link) {
+       list_for_each_entry(cl, &bus->devices, device_link) {
                if (cl->cldev && cl->cldev->me_cl &&
                    !uuid_le_cmp(uuid, *mei_me_cl_uuid(cl->cldev->me_cl)))
                        return cl;
@@ -557,7 +557,7 @@ void mei_cl_bus_remove_devices(struct mei_device *bus)
        struct mei_cl *cl, *next;
 
        mutex_lock(&bus->device_lock);
-       list_for_each_entry_safe(cl, next, &bus->device_list, device_link) {
+       list_for_each_entry_safe(cl, next, &bus->devices, device_link) {
                if (cl->cldev)
                        mei_cl_remove_device(cl->cldev);
 
diff --git a/drivers/misc/mei/init.c b/drivers/misc/mei/init.c
index 94514b2c7a50..64331a5ce990 100644
--- a/drivers/misc/mei/init.c
+++ b/drivers/misc/mei/init.c
@@ -388,7 +388,7 @@ void mei_device_init(struct mei_device *dev,
 {
        /* setup our list array */
        INIT_LIST_HEAD(&dev->file_list);
-       INIT_LIST_HEAD(&dev->device_list);
+       INIT_LIST_HEAD(&dev->devices);
        INIT_LIST_HEAD(&dev->me_clients);
        mutex_init(&dev->device_lock);
        init_rwsem(&dev->me_clients_rwsem);
diff --git a/drivers/misc/mei/nfc.c b/drivers/misc/mei/nfc.c
index 51a864a2b2b5..9bd76cda1608 100644
--- a/drivers/misc/mei/nfc.c
+++ b/drivers/misc/mei/nfc.c
@@ -357,7 +357,7 @@ int mei_nfc_host_init(struct mei_device *bus, struct 
mei_me_client *me_cl)
                goto err;
        }
 
-       list_add_tail(&cl_info->device_link, &bus->device_list);
+       list_add_tail(&cl_info->device_link, &bus->devices);
 
        ndev->cl_info = cl_info;
 
@@ -367,7 +367,7 @@ int mei_nfc_host_init(struct mei_device *bus, struct 
mei_me_client *me_cl)
                goto err;
        }
 
-       list_add_tail(&cl->device_link, &bus->device_list);
+       list_add_tail(&cl->device_link, &bus->devices);
 
        ndev->cl = cl;
 
diff --git a/drivers/misc/mei/mei_dev.h b/drivers/misc/mei/mei_dev.h
index bc65fb42aea9..2a1ab7958734 100644
--- a/drivers/misc/mei/mei_dev.h
+++ b/drivers/misc/mei/mei_dev.h
@@ -446,7 +446,7 @@ const char *mei_pg_state_str(enum mei_pg_state state);
  * @init_work   : work item for the device init
  * @reset_work  : work item for the device reset
  *
  * @device_list : mei client bus list
  *
  * @dbgfs_dir   : debugfs mei root directory
  *
@@ -541,8 +541,7 @@ struct mei_device {
        struct work_struct init_work;
        struct work_struct reset_work;
 
-       /* List of bus devices */
-       struct list_head device_list;
+       struct list_head devices;
 
 #if IS_ENABLED(CONFIG_DEBUG_FS)
        struct dentry *dbgfs_dir;
@@ -446,7 +446,7 @@ const char *mei_pg_state_str(enum mei_pg_state state);
  * @reset_work  : work item for the device reset
  *
- * @device_list : mei client bus list
+ * @devices     : mei client bus list
  *
  * @dbgfs_dir   : debugfs mei root directory
-- 
2.4.2

--
To unsubscribe from this list: send the line "unsubscribe linux-kernel" in
the body of a message to [email protected]
More majordomo info at  http://vger.kernel.org/majordomo-info.html
Please read the FAQ at  http://www.tux.org/lkml/

Reply via email to